import{d as u,eA as b,J as f,b as y,c as g,u as _}from"./outputWidgets.800838e3.js";import{a as w}from"./asyncComputed.982dc1f5.js";import"./router.ba9fc25a.js";import{M as n}from"./member.c9cddc35.js";import"./index.46095ec8.js";import{C as I}from"./CrudView.b259bd34.js";import"./Title.28613ffd.js";import"./index.cc2e9ddf.js";import"./gateway.872328f1.js";import"./activeRecord.9d8d542d.js";import"./pubsub.3b460539.js";import"./icons.93f59c4e.js";import"./index.e0615505.js";import"./Form.b8148ab8.js";import"./url.e7bb6b8a.js";import"./index.9edddcd4.js";import"./index.70fbd67e.js";import"./index.c4440e89.js";import"./index.960544fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c7c9e4b8-8e21-4db2-9265-598224f40935",e._sentryDebugIdIdentifier="sentry-dbid-c7c9e4b8-8e21-4db2-9265-598224f40935")}catch{}})();const F=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.84eacf48.js.map
