import{S as c}from"./Sidebar.4702c88a.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.6c5097b1.js";import{G as d,H as l,I as u}from"./icons.93f59c4e.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.800838e3.js";import{a as w}from"./asyncComputed.982dc1f5.js";import"./router.ba9fc25a.js";import{O as z}from"./organization.ef681389.js";import"./index.46095ec8.js";import{B as h}from"./BaseLayout.26c0e2f4.js";import"./Tooltip.04c0b4a5.js";import"./logo.084e5d7c.js";import"./index.e0615505.js";import"./Title.28613ffd.js";import"./index.960544fb.js";import"./index.23ff5dbe.js";import"./index.cc2e9ddf.js";import"./gateway.872328f1.js";import"./activeRecord.9d8d542d.js";import"./pubsub.3b460539.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="5a65b7ad-890f-4ec2-aa98-4adf31523c5c",a._sentryDebugIdIdentifier="sentry-dbid-5a65b7ad-890f-4ec2-aa98-4adf31523c5c")}catch{}})();const q=b({__name:"Organization",setup(a){const n=f().params.organizationId,{result:e}=w(()=>z.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.6d03904e.js.map
