import{d as y,ez as g,eA as v,r as k,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.800838e3.js";import{S as h,L as w}from"./SmartConsole.064f9282.js";import{a as x}from"./asyncComputed.982dc1f5.js";import{H as B}from"./hooks.e7ca1357.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.7bac205e.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.de73985e.js";import{B as I}from"./BaseLayout.26c0e2f4.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.af24bae0.js";import{c as A}from"./index.23ff5dbe.js";import{A as b,T as D}from"./TabPane.f110364a.js";import"./forms.ebcd7a71.js";import"./activeRecord.9d8d542d.js";import"./pubsub.3b460539.js";import"./dashes.b53773aa.js";import"./index.cc2e9ddf.js";import"./jobs.c91fe07e.js";import"./workspaces.d202f7b4.js";import"./url.e7bb6b8a.js";import"./icons.93f59c4e.js";import"./Title.28613ffd.js";import"./index.70fbd67e.js";import"./uuid.068c86dd.js";import"./ant-design.74cbd470.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.d9e0384d.js";import"./RunButton.vue_vue_type_script_setup_true_lang.e9630b92.js";import"./index.143d8479.js";import"./index.c4440e89.js";import"./CollapsePanel.8fc227e9.js";import"./index.960544fb.js";import"./index.271ff5e3.js";import"./index.9edddcd4.js";import"./Form.b8148ab8.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="68387dbe-e1d9-4f2b-b6f3-e77bf4f68b64",i._sentryDebugIdIdentifier="sentry-dbid-68387dbe-e1d9-4f2b-b6f3-e77bf4f68b64")}catch{}})();const fe=y({__name:"HookEditor",setup(i){const m=g(),f=v(),l=k(null),o=k("test");function _(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(f.params.hookPath)),c=w.create();return(R,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:_},{footer:a(()=>[u(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(b),{key:"test",tab:"Test"}),u(e(b),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:l,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=l.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{fe as default};
//# sourceMappingURL=HookEditor.dc50b453.js.map
