import{W as i}from"./outputWidgets.800838e3.js";import{c as d,d as c}from"./index.534faa1d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="f2047d30-135b-466d-a29a-610f8165a622",e._sentryDebugIdIdentifier="sentry-dbid-f2047d30-135b-466d-a29a-610f8165a622")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=d(c),b=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{b as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.9fee253f.js.map
