var v=Object.defineProperty;var P=(a,e,t)=>e in a?v(a,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):a[e]=t;var m=(a,e,t)=>(P(a,typeof e!="symbol"?e+"":e,t),t);import{d as k,r as x,eA as _,J as D,b as $,eu as j,f as l,u as d,w as u,bg as N,aJ as w,eC as M}from"./outputWidgets.800838e3.js";import{a as T}from"./asyncComputed.982dc1f5.js";import{P as E}from"./project.0458df14.js";import"./router.ba9fc25a.js";import{M as B}from"./member.c9cddc35.js";import{C as y}from"./gateway.872328f1.js";import{A as V}from"./activeRecord.9d8d542d.js";import"./index.46095ec8.js";import{q as J}from"./icons.93f59c4e.js";import{C as K}from"./CrudView.b259bd34.js";import{f as R}from"./index.b048d0fb.js";import{A as S,a as U}from"./index.e0615505.js";import{M as q}from"./Title.28613ffd.js";import"./index.cc2e9ddf.js";import"./pubsub.3b460539.js";import"./Form.b8148ab8.js";import"./url.e7bb6b8a.js";import"./index.9edddcd4.js";import"./index.70fbd67e.js";import"./index.c4440e89.js";import"./index.960544fb.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="a9096069-61a7-4c11-9783-91b37c31ae7d",a._sentryDebugIdIdentifier="sentry-dbid-a9096069-61a7-4c11-9783-91b37c31ae7d")}catch{}})();class z{constructor(){m(this,"urlPath","api-keys")}async create({projectId:e,name:t}){return y.post(`projects/${e}/${this.urlPath}`,{name:t})}async delete(e,t){await y.delete(`projects/${e}/${this.urlPath}/${t}`)}async list(e){return y.get(`projects/${e}/${this.urlPath}`)}async get(){throw new Error("Not implemented")}async update(){throw new Error("Not implemented")}}const p=new z;class s{constructor(e){m(this,"record");this.record=V.create(p,e,"id")}static async list(e){return(await p.list(e)).map(f=>new s(f))}static async create(e){const t=await p.create(e);return new s(t)}static async delete(e,t){await p.delete(e,t)}get id(){return this.record.get("id")}get name(){return this.record.get("name")}async save(){await this.record.save()}get createdAt(){return new Date(this.record.get("createdAt"))}hasChanges(){return this.record.hasChanges()}get ownerId(){return this.record.get("createdBy")}get value(){var e;return(e=this.record.get("value"))!=null?e:null}}const pe=k({__name:"ApiKeys",setup(a){const e=x(null),t=[{key:"name",label:"API key name"}],c=_().params.projectId,{loading:A,result:I,refetch:g}=T(async()=>Promise.all([s.list(c),E.get(c).then(r=>B.list(r.organizationId))]).then(([r,o])=>r.map(n=>({apiKey:n,member:o.find(i=>i.authorId===n.ownerId)})))),C=async r=>{const o=await s.create({projectId:c,name:r.name});g(),e.value=o.value},b=D(()=>{var r,o;return{columns:[{name:"Name"},{name:"Creation date"},{name:"Owner"},{name:"Actions",align:"right"}],rows:(o=(r=I.value)==null?void 0:r.map(({apiKey:n,member:i})=>{var h;return{key:n.id,cells:[{text:n.name},{text:R(n.createdAt,Date.now(),{addSuffix:!0})},{text:(h=i==null?void 0:i.email)!=null?h:"Unknown"},{text:"actions",actions:[{label:"Delete",icon:J,dangerous:!0,onClick:async()=>{await s.delete(c,n.id),g()}}]}]}}))!=null?o:[]}});return(r,o)=>($(),j(N,null,[l(K,{"entity-name":"API key","create-button-text":"Create API Key",loading:d(A),title:"API Keys",description:"API Keys are used to deploy your app from the local editor.","empty-title":"No API keys here yet",table:b.value,fields:t,onCreate:C},null,8,["loading","table"]),l(d(q),{open:!!e.value,title:"Api key generated",onCancel:o[0]||(o[0]=n=>e.value=null)},{footer:u(()=>[]),default:u(()=>[l(d(S),null,{default:u(()=>[w("Your API key was successfully generated. Use this code to login on your local development environment or deploy using CI")]),_:1}),l(d(U),{code:"",copyable:""},{default:u(()=>[w(M(e.value),1)]),_:1})]),_:1},8,["open"])],64))}});export{pe as default};
//# sourceMappingURL=ApiKeys.42a02734.js.map
