import{d as s,b as a,c as r,w as i,aJ as c,u as d,c4 as p}from"./outputWidgets.800838e3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="64b758bf-32eb-4a63-945f-a9665639d7dd",t._sentryDebugIdIdentifier="sentry-dbid-64b758bf-32eb-4a63-945f-a9665639d7dd")}catch{}})();class f{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}async getProjectInfo(){return(await fetch("/_editor/api/project-info")).json()}}const l=new f,b=s({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var o;return a(),r(d(p),{class:"docs-button",href:`https://docs.abstra.io/${(o=e.path)!=null?o:""}`,target:"_blank"},{default:i(()=>[c(" Docs ")]),_:1},8,["href"])}}});export{b as _,l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.de73985e.js.map
