import"./outputWidgets.800838e3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5b2fe4cd-7918-47b2-b44a-8eb974860273",e._sentryDebugIdIdentifier="sentry-dbid-5b2fe4cd-7918-47b2-b44a-8eb974860273")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.e7bb6b8a.js.map
