import{x as t,b as s,eu as d}from"./outputWidgets.800838e3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d15c901b-f8f0-42b7-85b9-3cdb981b53d5",e._sentryDebugIdIdentifier="sentry-dbid-d15c901b-f8f0-42b7-85b9-3cdb981b53d5")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.afb20f4c.js.map
