import{x as o,a,b as i,c,g as d,h as p,_,i as u,T as f,j as l,P as h,C as m,M as y,s as g,k as s,l as v,m as b,n as w,p as I}from"./outputWidgets.800838e3.js";import{u as k}from"./index.c55f977a.js";import"./pubsub.3b460539.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c4913915-09af-40d2-8368-3f82d30f1c93",e._sentryDebugIdIdentifier="sentry-dbid-c4913915-09af-40d2-8368-3f82d30f1c93")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.ad140aec.js"),["assets/Player.ad140aec.js","assets/index.cc2e9ddf.js","assets/outputWidgets.800838e3.js","assets/outputWidgets.e6401203.css","assets/uuid.068c86dd.js","assets/broker.497b1c75.js","assets/index.c55f977a.js","assets/pubsub.3b460539.js","assets/executeJs.a7ef7cce.js","assets/icons.93f59c4e.js","assets/CircularLoading.760eaaec.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.3d115f65.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.d86e1c08.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.98102695.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.665715fc.js","assets/broker.1fe265d9.css","assets/DashPlayer.c200eebd.js","assets/geometryUtils.ff83ce65.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.982dc1f5.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>v(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",g),s(e,b),s(e,w),s(e,I)})();
//# sourceMappingURL=player.42064b0f.js.map
