import{cG as r}from"./outputWidgets.800838e3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="8a9291d3-95b3-473d-bdb9-4e24adcd10e0",e._sentryDebugIdIdentifier="sentry-dbid-8a9291d3-95b3-473d-bdb9-4e24adcd10e0")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.fc5c8185.js.map
