import{m as k,l as S}from"./icons.93f59c4e.js";import{d as _,J as b,b as i,eu as n,e as o,bg as g,eB as R,ey as c,eC as v,x as h,H as I,u as f,ew as r,f as N,I as w,c as C,eD as B,eE as D}from"./outputWidgets.800838e3.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="846968bc-f95f-4420-9280-f00b152a4ac1",a._sentryDebugIdIdentifier="sentry-dbid-846968bc-f95f-4420-9280-f00b152a4ac1")}catch{}})();const E={class:"sidebar-content"},$={class:"section"},P=["onClick"],U=_({__name:"Sidebar",props:{currentRuntime:{},displaySidebar:{type:Boolean},forceResponsivity:{}},emits:["selectRuntime","closeSidebar"],setup(a,{emit:t}){const l=a,u=b(()=>l.currentRuntime.runtimeType==="dash"),d=s=>{e(s.id)||t("selectRuntime",s)},p=b(()=>l.currentRuntime.sidebar.filter(s=>s.visible)),e=s=>s===l.currentRuntime.id;return(s,y)=>(i(),n("div",{class:c(["sidebar",s.forceResponsivity,{open:s.displaySidebar,dash:u.value}])},[o("div",E,[o("div",$,[(i(!0),n(g,null,R(p.value,m=>(i(),n("div",{key:m.id,class:c(["item",{active:e(m.id)}]),onClick:G=>d(m)},[o("div",{class:c(["item-title",{open:s.displaySidebar}])},v(m.name),3)],10,P))),128))])])],2))}});const T=h(U,[["__scopeId","data-v-09ca60c8"]]),V=a=>(B("data-v-2aa60bdb"),a=a(),D(),a),z={class:"left-side"},F=["d"],H={key:1,class:"brand"},J=["src"],L={key:1,class:"brand-name"},j=V(()=>o("div",null,null,-1)),q={key:0,class:"signed-email"},A=_({__name:"PlayerNavbar",props:{runtime:{},userEmail:{},forceResponsivity:{}},emits:["logout","navigate"],setup(a,{emit:t}){const l=a,u=I({displaySidebar:!1}),d=b(()=>{const e=l.runtime.sidebar;return!e||e.length==0?!1:e.some(s=>s.visible)}),p=e=>t("navigate",e);return(e,s)=>(i(),n(g,null,[d.value||e.runtime.logoUrl||e.runtime.brandName||e.userEmail?(i(),n("div",{key:0,class:c(["navbar",(e.runtime.runtimeType=="dash"||d.value)&&"background"])},[o("div",z,[d.value?(i(),n("svg",{key:0,class:c(["sidebar-menu-icon",e.forceResponsivity,{dash:e.runtime.runtimeType=="dash"}]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:s[0]||(s[0]=y=>u.displaySidebar=!u.displaySidebar)},[o("path",{d:f(k)},null,8,F)],2)):r("",!0),e.runtime.logoUrl||e.runtime.brandName?(i(),n("div",H,[e.runtime.logoUrl?(i(),n("img",{key:0,src:e.runtime.logoUrl,class:"logo-image"},null,8,J)):r("",!0),e.runtime.brandName?(i(),n("p",L,v(e.runtime.brandName),1)):r("",!0)])):r("",!0)]),j,e.userEmail?(i(),n("div",q,[o("span",null,v(e.userEmail),1),N(w,{width:"20",height:"20",class:"logout",path:f(S),fill:"var(--color-main)",onClick:s[1]||(s[1]=y=>t("logout"))},null,8,["path"])])):r("",!0)],2)):r("",!0),d.value?(i(),C(T,{key:1,"current-runtime":e.runtime,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:p},null,8,["current-runtime","display-sidebar","force-responsivity"])):r("",!0)],64))}});const O=h(A,[["__scopeId","data-v-2aa60bdb"]]);export{O as P};
//# sourceMappingURL=PlayerNavbar.3d115f65.js.map
