import{d as u,eA as b,J as m,a as g,b as v,c as f,w as i,f as s}from"./outputWidgets.800838e3.js";import{B as _}from"./BaseLayout.26c0e2f4.js";import{a as h}from"./asyncComputed.982dc1f5.js";import{P as y}from"./project.0458df14.js";import"./router.ba9fc25a.js";import{O as z}from"./organization.ef681389.js";import"./index.46095ec8.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.6c5097b1.js";import{S as I}from"./Sidebar.4702c88a.js";import{k as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.93f59c4e.js";import"./gateway.872328f1.js";import"./activeRecord.9d8d542d.js";import"./pubsub.3b460539.js";import"./Title.28613ffd.js";import"./index.cc2e9ddf.js";import"./logo.084e5d7c.js";import"./index.e0615505.js";import"./index.960544fb.js";import"./index.23ff5dbe.js";import"./Tooltip.04c0b4a5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="80c894d8-592d-4795-a193-19b137ad1964",o._sentryDebugIdIdentifier="sentry-dbid-80c894d8-592d-4795-a193-19b137ad1964")}catch{}})();const aa=u({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return v(),f(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{aa as default};
//# sourceMappingURL=Project.1057b350.js.map
