import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.800838e3.js";import{S as w,L as j}from"./SmartConsole.064f9282.js";import{a as x}from"./asyncComputed.982dc1f5.js";import{J as I}from"./jobs.c91fe07e.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.7bac205e.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.de73985e.js";import{B as S}from"./BaseLayout.26c0e2f4.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.9461cfaf.js";import{c as D}from"./index.23ff5dbe.js";import{A as _,T as R}from"./TabPane.f110364a.js";import"./forms.ebcd7a71.js";import"./activeRecord.9d8d542d.js";import"./pubsub.3b460539.js";import"./dashes.b53773aa.js";import"./index.cc2e9ddf.js";import"./hooks.e7ca1357.js";import"./workspaces.d202f7b4.js";import"./url.e7bb6b8a.js";import"./icons.93f59c4e.js";import"./Title.28613ffd.js";import"./index.70fbd67e.js";import"./uuid.068c86dd.js";import"./ant-design.74cbd470.js";import"./RunButton.vue_vue_type_script_setup_true_lang.e9630b92.js";import"./index.534faa1d.js";import"./index.9edddcd4.js";import"./dayjs.a452fbc3.js";import"./Form.b8148ab8.js";import"./index.960544fb.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="3fad78d3-4937-4202-a1f1-36585ea74b2f",i._sentryDebugIdIdentifier="sentry-dbid-3fad78d3-4937-4202-a1f1-36585ea74b2f")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),f=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),c=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.13eb8f07.js.map
